# Table of Contents

- [updating-tag-related-to-time-model](<./updating-tag-related-to-time-model.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Categorizing Applications Using the TIME Framework with Tags](<./Categorizing-Applications-Using-the-TIME-Framework-with-Tags.md>)
  - [Getting Started with Azure Functions](<./Categorizing-Applications-Using-the-TIME-Framework-with-Tags/Getting-Started-with-Azure-Functions.md>)
  - [Step 1: Prepare Your Environment](<./Categorizing-Applications-Using-the-TIME-Framework-with-Tags/Step-1-Prepare-Your-Environment.md>)
  - [Step 2: Create a Tag Group](<./Categorizing-Applications-Using-the-TIME-Framework-with-Tags/Step-2-Create-a-Tag-Group.md>)
  - [Step 3: Create a Webhook](<./Categorizing-Applications-Using-the-TIME-Framework-with-Tags/Step-3-Create-a-Webhook.md>)
  - [Step 4: Set Azure Environment Variables](<./Categorizing-Applications-Using-the-TIME-Framework-with-Tags/Step-4-Set-Azure-Environment-Variables.md>)
